==> fullscreen-0.1.3.tgz: package/es/index.js <==
import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
/** Libraries **/
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';

/** Function **/
import fscreen from './fullScreen';

var FullScreen = function (_PureComponent) {
  _inherits(FullScreen, _PureComponent);

  function FullScreen(props) {
    _classCallCheck(this, FullScreen);

    var _this = _possibleConstructorReturn(this, (FullScreen.__proto__ || _Object$getPrototypeOf(FullScreen)).call(this, props));

    _this.onFullScreen = _this.onFullScreen.bind(_this);
    _this.onFullScreenChange = _this.onFullScreenChange.bind(_this);
    _this.onExit = _this.onExit.bind(_this);

    _this.fscreenRef = React.createRef();
    return _this;
  }

  _createClass(FullScreen, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      fscreen.addEventListener('fullscreenchange', this.onFullScreenChange);
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate() {
      var isfscreenElement = fscreen.fullscreenElement === this.fscreenRef.current;
      if (isfscreenElement && !this.props.isEnabled) {
        this.onExit();
      } else if (!isfscreenElement && this.props.isEnabled) {
        this.onFullScreen();
      }
    }
  }, {
    key: 'shouldComponentUpdate',
    value: function shouldComponentUpdate(nextProps) {
      return nextProps.isEnabled !== this.props.isEnabled;
    }
  }, {
    key: 'onFullScreen',
    value: function onFullScreen() {
      fscreen.isFullscreenEnabled && fscreen.requestFullscreen(this.fscreenRef.current);
    }
  }, {
    key: 'onExit',
    value: function onExit() {
      fscreen.isFullscreenEnabled && fscreen.exitFullscreen();
    }
  }, {
    key: 'onFullScreenChange',
    value: function onFullScreenChange() {
      var onChange = this.props.onChange;

      onChange && onChange(fscreen.fullscreenElement === this.fscreenRef.current);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      fscreen.removeEventListener('fullscreenchange', this.onFullScreenChange);
      this.fscreenRef = null;
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          isEnabled = _props.isEnabled,
          className = _props.className,
          children = _props.children;

      if (isEnabled) {
        className += ' fullscreenEnabled';
      }
      return React.createElement(
        'div',
        { className: className, ref: this.fscreenRef },
        children
      );
    }
  }]);

  return FullScreen;
}(PureComponent);

export default FullScreen;


FullScreen.defaultProps = {
  isEnabled: false,
  className: ''
};

FullScreen.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  isEnabled: PropTypes.bool.isRequired,
  onChange: PropTypes.func
};

==> fullscreen-0.1.4.tgz: package/es/index.js <==
import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
/** Libraries **/
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';

/** Function **/
import fscreen from './fullScreen';

// css
import style from './fullscreen.module.css';

var FullScreen = function (_PureComponent) {
  _inherits(FullScreen, _PureComponent);

  function FullScreen(props) {
    _classCallCheck(this, FullScreen);

    var _this = _possibleConstructorReturn(this, (FullScreen.__proto__ || _Object$getPrototypeOf(FullScreen)).call(this, props));

    _this.onFullScreen = _this.onFullScreen.bind(_this);
    _this.onFullScreenChange = _this.onFullScreenChange.bind(_this);
    _this.onExit = _this.onExit.bind(_this);

    _this.fscreenRef = React.createRef();
    return _this;
  }

  _createClass(FullScreen, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      fscreen.addEventListener('fullscreenchange', this.onFullScreenChange);
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate() {
      var isfscreenElement = fscreen.fullscreenElement === this.fscreenRef.current;
      if (isfscreenElement && !this.props.isEnabled) {
        this.onExit();
      } else if (!isfscreenElement && this.props.isEnabled) {
        this.onFullScreen();
      }
    }
  }, {
    key: 'shouldComponentUpdate',
    value: function shouldComponentUpdate(nextProps) {
      return nextProps.isEnabled !== this.props.isEnabled;
    }
  }, {
    key: 'onFullScreen',
    value: function onFullScreen() {
      fscreen.isFullscreenEnabled && fscreen.requestFullscreen(this.fscreenRef.current);
    }
  }, {
    key: 'onExit',
    value: function onExit() {
      fscreen.isFullscreenEnabled && fscreen.exitFullscreen();
    }
  }, {
    key: 'onFullScreenChange',
    value: function onFullScreenChange() {
      var onChange = this.props.onChange;

      onChange && onChange(fscreen.fullscreenElement === this.fscreenRef.current);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      fscreen.removeEventListener('fullscreenchange', this.onFullScreenChange);
      this.fscreenRef = null;
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          isEnabled = _props.isEnabled,
          className = _props.className,
          children = _props.children;

      if (isEnabled) {
        className += ' fullscreenEnabled';
      }
      return React.createElement(
        'div',
        { className: className + ' ' + style.fullScreen, ref: this.fscreenRef },
        children
      );
    }
  }]);

  return FullScreen;
}(PureComponent);

export default FullScreen;


FullScreen.defaultProps = {
  isEnabled: false,
  className: ''
};

FullScreen.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  isEnabled: PropTypes.bool.isRequired,
  onChange: PropTypes.func
};
